@@ -1,8 +1,8 @@
 import re
+import six
 import logging
 
 from six import Iterator
-from six.moves import zip_longest as izip_longest
 
 from pymarc.exceptions import BaseAddressInvalid, RecordLeaderInvalid, \
         BaseAddressNotFound, RecordDirectoryInvalid, NoFieldsFound, \
@@ -12,6 +12,8 @@ from pymarc.field import Field, SUBFIELD_INDICATOR, END_OF_FIELD, \
         map_marc8_field, RawField
 from pymarc.marc8 import marc8_to_unicode
 
+izip_longest = six.moves.zip_longest
+
 try:
     # the json module was included in the stdlib in python 2.6
     # http://docs.python.org/library/json.html
@@ -406,7 +408,7 @@ class Record(Iterator):
             title = None 
         if title:
             try:
-                title += self['245']['b'] 
+                title += " " + self['245']['b'] 
             except TypeError: 
                 pass
         return title
@@ -499,18 +501,23 @@ class Record(Iterator):
         return self.get_fields('300')
 
     def publisher(self):
-        if self['260']:
-            return self['260']['b']
-        if self['264']:
-            return self['264']['b']
+        """
+        Note: 264 field with second indicator '1' indicates publisher.
+        """
+        for f in self.get_fields('260', '264'):
+            if self['260']:
+                return self['260']['b']
+            if self['264'] and f.indicator2 == '1':
+                return self['264']['b']
 
         return None
 
     def pubyear(self):
-        if self['260']:
-            return self['260']['c']
-        elif self['264']:
-            return self['264']['c']
+        for f in self.get_fields('260', '264'):
+            if self['260']:
+                return self['260']['c']
+            if self['264'] and f.indicator2 == '1':
+                return self['264']['c']
 
         return None
 
